% viewRBF(xy, f)
%
% Make a 3D plot of the thin-plate spline RBF interpolant through
% points (xy,f). See solveRBF for more details.

function viewRBF(xy, f)

h=ishold;
if ~h
  hold on;
end

% get the RBF coefficients
coeffs=solveRBF(xy, f);

% figure out an appropriate size grid to evaluate on
xmin=min(xy(:,1)); xmax=max(xy(:,1));
ymin=min(xy(:,2)); ymax=max(xy(:,2));
width=1.1*max(xmax-xmin, ymax-ymin);
ex=linspace(0.5*(xmin+xmax-width), 0.5*(xmin+xmax+width), 50);
ey=linspace(0.5*(ymin+ymax-width), 0.5*(ymin+ymax+width), 50);
evalx=ones(50,1)*ex;
evaly=ey'*ones(1,50);

% do the evaluation
evalf=evalRBF(xy, coeffs, evalx, evaly);

% plot the mesh and the interpolated points
mesh(ex, ey, evalf);
plot3(xy(:,1),xy(:,2),f,'ko');

if ~h
  hold off;
end
